**To delete a parameter**

This ``delete-parameter`` example deletes the specified single parameter. ::

    aws ssm delete-parameter \
        --name "MyParameter"

This command produces no output.

For more information, see `Working with Parameters <https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-paramstore-working.html>`_ in the *AWS Systems Manager User Guide*.
